@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2012 David Green and others.
+ * Copyright (c) 2007, 2013 David Green and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -21,11 +21,13 @@ import java.util.regex.Pattern;
 
 import junit.framework.TestCase;
 
+import org.eclipse.mylyn.wikitext.core.osgi.OsgiServiceLocator;
 import org.eclipse.mylyn.wikitext.core.parser.DocumentBuilder.SpanType;
 import org.eclipse.mylyn.wikitext.core.parser.MarkupParser;
 import org.eclipse.mylyn.wikitext.core.parser.builder.HtmlDocumentBuilder;
 import org.eclipse.mylyn.wikitext.core.parser.builder.RecordingDocumentBuilder;
 import org.eclipse.mylyn.wikitext.core.parser.builder.RecordingDocumentBuilder.Event;
+import org.eclipse.mylyn.wikitext.core.parser.markup.MarkupLanguage;
 import org.eclipse.mylyn.wikitext.core.parser.markup.MarkupLanguageConfiguration;
 import org.eclipse.mylyn.wikitext.tests.TestUtil;
 
@@ -55,6 +57,12 @@ public class TextileLanguageTest extends TestCase {
 		parser.setMarkupLanguage(markupLanguage);
 	}
 
+	public void testDiscoverable() {
+		MarkupLanguage language = OsgiServiceLocator.getApplicableInstance().getMarkupLanguage("Textile");
+		assertNotNull(language);
+		assertTrue(language instanceof TextileLanguage);
+	}
+
 	public void testIsDetectingRawHyperlinks() {
 		assertFalse(markupLanguage.isDetectingRawHyperlinks());
 	}
@@ -158,6 +166,12 @@ public class TextileLanguageTest extends TestCase {
 		assertTrue(html.contains("<code>code text:</code>"));
 	}
 
+	public void testDeleted() {
+		String html = parser.parseToHtml("one -two three-four five- six");
+		TestUtil.println("HTML: \n" + html);
+		assertTrue(html.contains("<del>two three-four five</del>"));
+	}
+
 	public void testAdjacentPhraseModifiers() {
 		String html = parser.parseToHtml("_emphasis_ *strong text*");
 		TestUtil.println("HTML: \n" + html);
@@ -1539,4 +1553,5 @@ public class TextileLanguageTest extends TestCase {
 			assertTrue(html.contains("&amp; " + entity + ";"));
 		}
 	}
+
 }
