@@ -11,9 +11,12 @@
  *      Sascha Scholz (SAP) - improvements
  *      GitHub, Inc. - fixes for bug 354753
  *      Christian Trutz - improvements
+ *      Francois Chouinard - Added "LABELS" option on selected queries
+ *      Jacques Bouthillier - Bug 414253 Add support for Gerrit Dashboard
  *********************************************************************/
 package org.eclipse.mylyn.internal.gerrit.core.client;
 
+import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
@@ -31,10 +34,13 @@ import java.util.Map.Entry;
 import java.util.Set;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
+import java.util.zip.ZipInputStream;
 
 import org.apache.commons.httpclient.Cookie;
 import org.apache.commons.httpclient.HttpMethodBase;
 import org.apache.commons.httpclient.methods.GetMethod;
+import org.apache.commons.io.IOUtils;
+import org.apache.commons.lang.StringUtils;
 import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.OperationCanceledException;
@@ -50,6 +56,7 @@ import org.eclipse.mylyn.internal.gerrit.core.client.compat.ChangeDetailX;
 import org.eclipse.mylyn.internal.gerrit.core.client.compat.ChangeManageService;
 import org.eclipse.mylyn.internal.gerrit.core.client.compat.GerritConfigX;
 import org.eclipse.mylyn.internal.gerrit.core.client.compat.PatchDetailService;
+import org.eclipse.mylyn.internal.gerrit.core.client.compat.PatchScriptX;
 import org.eclipse.mylyn.internal.gerrit.core.client.compat.PatchSetPublishDetailX;
 import org.eclipse.mylyn.internal.gerrit.core.client.compat.ProjectAdminService;
 import org.eclipse.mylyn.internal.gerrit.core.client.compat.ProjectDetailX;
@@ -84,7 +91,6 @@ import com.google.gerrit.common.data.ApprovalDetail;
 import com.google.gerrit.common.data.ChangeDetail;
 import com.google.gerrit.common.data.ChangeListService;
 import com.google.gerrit.common.data.GerritConfig;
-import com.google.gerrit.common.data.PatchScript;
 import com.google.gerrit.common.data.PatchSetDetail;
 import com.google.gerrit.common.data.ReviewerResult;
 import com.google.gerrit.common.data.SingleListChangeInfo;
@@ -95,6 +101,7 @@ import com.google.gerrit.reviewdb.ApprovalCategoryValue;
 import com.google.gerrit.reviewdb.Change;
 import com.google.gerrit.reviewdb.ContributorAgreement;
 import com.google.gerrit.reviewdb.Patch;
+import com.google.gerrit.reviewdb.Patch.ChangeType;
 import com.google.gerrit.reviewdb.PatchLineComment;
 import com.google.gerrit.reviewdb.PatchSet;
 import com.google.gerrit.reviewdb.PatchSet.Id;
@@ -114,11 +121,15 @@ import com.google.gwtjsonrpc.client.VoidResult;
  * @author Christian Trutz
  * @author Sascha Scholz
  * @author Miles Parker
+ * @author Francois Chouinard
+ * @author Jacques Bouthillier
  */
 public class GerritClient extends ReviewsClient {
 
 	private static final Pattern GERRIT_VERSION_PATTERN = Pattern.compile("Powered by Gerrit Code Review (.+)</p>"); //$NON-NLS-1$
 
+	private static final String GET_LABELS_OPTION = "LABELS"; //$NON-NLS-1$
+
 	private abstract class Operation<T> implements AsyncCallback<T> {
 
 		private Throwable exception;
@@ -349,7 +360,7 @@ public class GerritClient extends ReviewsClient {
 			patchSetContent.setTargetDetail(targetDetail);
 		}
 		for (Patch patch : patchSetContent.getTargetDetail().getPatches()) {
-			PatchScript patchScript = getPatchScript(patch.getKey(), baseId, targetId, monitor);
+			PatchScriptX patchScript = getPatchScript(patch.getKey(), baseId, targetId, monitor);
 			if (patchScript != null) {
 				patchSetContent.putPatchScriptByPatchKey(patch.getKey(), patchScript);
 			}
@@ -384,17 +395,52 @@ public class GerritClient extends ReviewsClient {
 		return new GerritSystemInfo(version, contributorAgreements, account);
 	}
 
-	private PatchScript getPatchScript(final Patch.Key key, final PatchSet.Id leftId, final PatchSet.Id rightId,
+	private PatchScriptX getPatchScript(final Patch.Key key, final PatchSet.Id leftId, final PatchSet.Id rightId,
 			IProgressMonitor monitor) throws GerritException {
 		//final AccountDiffPreference diffPrefs = getDiffPreference(monitor);
 		//final AccountDiffPreference diffPrefs = new AccountDiffPreference(getAccount(monitor).getId());
 		final AccountDiffPreference diffPrefs = createAccountDiffPreference();
-		return execute(monitor, new Operation<PatchScript>() {
+		PatchScriptX patchScript = execute(monitor, new Operation<PatchScriptX>() {
 			@Override
 			public void execute(IProgressMonitor monitor) throws GerritException {
-				getPatchDetailService(monitor).patchScript(key, leftId, rightId, diffPrefs, this);
+				getPatchDetailService(monitor).patchScriptX(key, leftId, rightId, diffPrefs, this);
 			}
 		});
+		if (patchScript.isBinary()) {
+			if (patchScript.getChangeType() != ChangeType.ADDED) {
+				String keyBaseEncoded = encode(key.toString() + "^1"); //$NON-NLS-1$
+				patchScript.setBinaryA(fetchBinaryContent("/cat/" + keyBaseEncoded, monitor)); //$NON-NLS-1$
+			}
+			if (patchScript.getChangeType() != ChangeType.DELETED) {
+				String keyTargetEncoded = encode(key.toString() + "^0"); //$NON-NLS-1$
+				patchScript.setBinaryB(fetchBinaryContent("/cat/" + keyTargetEncoded, monitor)); //$NON-NLS-1$
+			}
+		}
+		return patchScript;
+	}
+
+	private byte[] fetchBinaryContent(String url, IProgressMonitor monitor) throws GerritException {
+		final TypeToken<Byte[]> byteArrayType = new TypeToken<Byte[]>() {
+		};
+		byte[] bin = executeGetRestRequest(url, byteArrayType.getType(), monitor);
+		if (isVersion27OrLater(monitor)) {
+			return bin;
+		} else if (isVersion26OrLater(monitor)) {
+			return unzip(bin);
+		}
+		return null;
+	}
+
+	private static byte[] unzip(byte[] zip) throws GerritException {
+		ZipInputStream zis = new ZipInputStream(new ByteArrayInputStream(zip));
+		try {
+			zis.getNextEntry(); // expecting a single entry
+			return IOUtils.toByteArray(zis);
+		} catch (IOException e) {
+			throw new GerritException(e);
+		} finally {
+			IOUtils.closeQuietly(zis);
+		}
 	}
 
 	private AccountDiffPreference createAccountDiffPreference() {
@@ -467,6 +513,9 @@ public class GerritClient extends ReviewsClient {
 		if (publishDetail.getLabels() == null && isVersion26OrLater(monitor)) {
 			ChangeInfo changeInfo = getChangeInfo(id.getParentKey().get(), monitor);
 			publishDetail.setLabels(changeInfo.convertToPermissionLabels());
+			if (publishDetail.getGiven() == null) {
+				publishDetail.setGiven(changeInfo.convertToPatchSetApprovals(id, getAccount(monitor)));
+			}
 		}
 		return publishDetail;
 	}
@@ -689,7 +738,7 @@ public class GerritClient extends ReviewsClient {
 			}
 		}
 		// the "self" alias is only supported in Gerrit 2.5 and later
-		return executeQueryRest(monitor, "owner:self OR reviewer:self"); //$NON-NLS-1$
+		return executeQueryRest(monitor, "owner:self OR reviewer:self", GET_LABELS_OPTION); //$NON-NLS-1$
 	}
 
 	private boolean hasJsonRpcApi(IProgressMonitor monitor) throws GerritException {
@@ -860,8 +909,36 @@ public class GerritClient extends ReviewsClient {
 		return getChangeDetail(id.get(), monitor);
 	}
 
+	/**
+	 * Sends a query for the changes visible to the caller to the gerrit server.
+	 * 
+	 * @param monitor
+	 *            A progress monitor
+	 * @param queryString
+	 *            The specific gerrit change query
+	 * @return a list of GerritQueryResults built from the parsed query result (ChangeInfo:s)
+	 * @throws GerritException
+	 */
 	public List<GerritQueryResult> executeQuery(IProgressMonitor monitor, final String queryString)
 			throws GerritException {
+		return executeQuery(monitor, queryString, GET_LABELS_OPTION);
+	}
+
+	/**
+	 * Sends a query for the changes visible to the caller to the gerrit server with the possibility of adding options
+	 * to the query.
+	 * 
+	 * @param monitor
+	 *            A progress monitor
+	 * @param queryString
+	 *            The specific gerrit change query
+	 * @param optionString
+	 *            Query options ("&o=" parameter). Only applicable for the REST API, ignored otherwise. May be null.
+	 * @return a list of GerritQueryResults built from the parsed query result (ChangeInfo:s)
+	 * @throws GerritException
+	 */
+	public List<GerritQueryResult> executeQuery(IProgressMonitor monitor, final String queryString, String optionString)
+			throws GerritException {
 		if (hasJsonRpcApi(monitor) && !restQueryAPIEnabled) {
 			try {
 				SingleListChangeInfo sl = execute(monitor, new Operation<SingleListChangeInfo>() {
@@ -880,7 +957,7 @@ public class GerritClient extends ReviewsClient {
 			}
 		}
 
-		return executeQueryRest(monitor, queryString);
+		return executeQueryRest(monitor, queryString, optionString);
 	}
 
 	private List<GerritQueryResult> convert(List<com.google.gerrit.common.data.ChangeInfo> changes) {
@@ -892,16 +969,43 @@ public class GerritClient extends ReviewsClient {
 		return results;
 	}
 
+	/**
+	 * Sends a query for the changes visible to the caller to the gerrit server. Uses the gerrit REST API.
+	 * 
+	 * @param monitor
+	 *            A progress monitor
+	 * @param queryString
+	 *            The specific gerrit change query
+	 * @return a list of GerritQueryResults built from the parsed query result (ChangeInfo:s)
+	 * @throws GerritException
+	 */
 	public List<GerritQueryResult> executeQueryRest(IProgressMonitor monitor, final String queryString)
 			throws GerritException {
-		try {
-			String uri = "/changes/?q=" + URLEncoder.encode(queryString, "UTF-8"); //$NON-NLS-1$ //$NON-NLS-2$
-			TypeToken<List<GerritQueryResult>> queryResultListType = new TypeToken<List<GerritQueryResult>>() {
-			};
-			return executeGetRestRequest(uri, queryResultListType.getType(), monitor);
-		} catch (UnsupportedEncodingException e) {
-			throw new GerritException(e);
+		return executeQueryRest(monitor, queryString, null);
+	}
+
+	/**
+	 * Sends a query for the changes visible to the caller to the gerrit server with the possibility of adding options
+	 * to the query. Uses the gerrit REST API.
+	 * 
+	 * @param monitor
+	 *            A progress monitor
+	 * @param queryString
+	 *            The specific gerrit change query
+	 * @param optionString
+	 *            Query options ("&o=" parameter). May be null or empty.
+	 * @return a list of GerritQueryResults built from the parsed query result (ChangeInfo:s)
+	 * @throws GerritException
+	 */
+	public List<GerritQueryResult> executeQueryRest(IProgressMonitor monitor, final String queryString,
+			String optionString) throws GerritException {
+		String uri = "/changes/?q=" + encode(queryString); //$NON-NLS-1$
+		if (StringUtils.isNotBlank(optionString)) {
+			uri += "&o=" + encode(optionString); //$NON-NLS-1$
 		}
+		TypeToken<List<GerritQueryResult>> queryResultListType = new TypeToken<List<GerritQueryResult>>() {
+		};
+		return executeGetRestRequest(uri, queryResultListType.getType(), monitor);
 	}
 
 	/**
@@ -1148,4 +1252,29 @@ public class GerritClient extends ReviewsClient {
 			}
 		});
 	}
+
+	public String toReviewId(String id, IProgressMonitor monitor) throws GerritException {
+		try {
+			Integer.parseInt(id);
+			return id;
+		} catch (NumberFormatException e) {
+			try {
+				List<GerritQueryResult> results = executeQuery(monitor, id);
+				if (results.size() != 1) {
+					throw new GerritException(NLS.bind("{0} is not a valid review ID", id)); //$NON-NLS-1$
+				}
+				return Integer.toString(results.get(0).getNumber());
+			} catch (GerritException e2) {
+				throw new GerritException(NLS.bind("{0} is not a valid review ID", id), e2); //$NON-NLS-1$
+			}
+		}
+	}
+
+	private static String encode(String string) throws GerritException {
+		try {
+			return URLEncoder.encode(string, "UTF-8"); //$NON-NLS-1$
+		} catch (UnsupportedEncodingException e) {
+			throw new GerritException(e);
+		}
+	}
 }
