@@ -24,6 +24,7 @@ import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.NullProgressMonitor;
 import org.eclipse.mylyn.bugzilla.tests.support.BugzillaFixture;
+import org.eclipse.mylyn.bugzilla.tests.support.BugzillaTestSupportUtil;
 import org.eclipse.mylyn.commons.net.AuthenticationCredentials;
 import org.eclipse.mylyn.commons.net.AuthenticationType;
 import org.eclipse.mylyn.commons.sdk.util.CommonTestUtil.PrivilegeLevel;
@@ -31,6 +32,7 @@ import org.eclipse.mylyn.internal.bugzilla.core.BugzillaAttribute;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaClient;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaStatus;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaTaskDataHandler;
+import org.eclipse.mylyn.internal.bugzilla.core.BugzillaVersion;
 import org.eclipse.mylyn.internal.bugzilla.core.IBugzillaConstants;
 import org.eclipse.mylyn.internal.tasks.core.TaskAttachment;
 import org.eclipse.mylyn.internal.tasks.core.TaskTask;
@@ -258,9 +260,7 @@ public class BugzillaAttachmentHandlerTest extends AbstractBugzillaTest {
 					new NullProgressMonitor());
 			fail("never reach this!");
 		} catch (Exception e) {
-			assertEquals(
-					"file is empty:  The file you are trying to attach is empty, does not exist, or you don't have permission to read it.",
-					e.getMessage());
+			assertFileEmptyError(e);
 		}
 
 		taskData = BugzillaFixture.current().getTask(taskData.getTaskId(), client);
@@ -285,9 +285,7 @@ public class BugzillaAttachmentHandlerTest extends AbstractBugzillaTest {
 					new NullProgressMonitor());
 			fail("never reach this!");
 		} catch (Exception e) {
-			assertEquals(
-					"file is empty:  The file you are trying to attach is empty, does not exist, or you don't have permission to read it.",
-					e.getMessage());
+			assertFileEmptyError(e);
 		}
 
 		taskData = BugzillaFixture.current().getTask(taskData.getTaskId(), client);
@@ -313,6 +311,16 @@ public class BugzillaAttachmentHandlerTest extends AbstractBugzillaTest {
 		assertTrue(attachFile.delete());
 	}
 
+	private void assertFileEmptyError(Exception e) {
+		if (BugzillaFixture.current().getBugzillaVersion().compareTo(BugzillaVersion.BUGZILLA_4_5_2) >= 0) {
+			assertEquals("An unknown repository error has occurred: file is empty", e.getMessage());
+		} else {
+			assertEquals(
+					"file is empty:  The file you are trying to attach is empty, does not exist, or you don't have permission to read it.",
+					e.getMessage());
+		}
+	}
+
 	public void testAttachmentToken() throws Exception {
 		TaskData taskData = BugzillaFixture.current().createTask(PrivilegeLevel.USER, null, null);
 		assertNotNull(taskData);
@@ -472,6 +480,8 @@ public class BugzillaAttachmentHandlerTest extends AbstractBugzillaTest {
 	}
 
 	public void testContextAttachFailure() throws Exception {
+		// use the client's repository when setting credentials below
+		repository = client.getTaskRepository();
 		TaskData taskData = BugzillaFixture.current().createTask(PrivilegeLevel.USER, null, null);
 		assertNotNull(taskData);
 		ITask task = TasksUi.getRepositoryModel().createTask(repository, taskData.getTaskId());
@@ -501,7 +511,7 @@ public class BugzillaAttachmentHandlerTest extends AbstractBugzillaTest {
 			connector.getTaskAttachmentHandler().postContent(repository, task, attachment,
 					attachmentMapper.getComment(), attrAttachment, new NullProgressMonitor());
 		} catch (CoreException e) {
-			assertTrue(e.getMessage().contains("invalid username or password"));
+			assertTrue(BugzillaTestSupportUtil.isInvalidLogon(e));
 			assertEquals(SynchronizationState.SYNCHRONIZED, task.getSynchronizationState());
 			return;
 		}
