@@ -615,4 +615,34 @@ public abstract class AbstractRepositoryConnector {
 		throw new UnsupportedOperationException();
 	}
 
+	/**
+	 * Validates the connection to {@code repository} and returns information about the repository. This typically
+	 * requires connecting to the repository.
+	 * <p>
+	 * Throws {@link UnsupportedOperationException} if not implemented by clients.
+	 * 
+	 * @param repository
+	 *            the repository
+	 * @param monitor
+	 *            a progress monitor
+	 * @throws CoreException
+	 *             thrown in case the operation fails
+	 * @since 3.11
+	 */
+	public RepositoryInfo validateRepository(TaskRepository repository, IProgressMonitor monitor) throws CoreException {
+		throw new UnsupportedOperationException();
+	}
+
+	/**
+	 * Set the category of the {@code repository} to the default TaskRepository.CATEGORY_BUGS.
+	 * <p>
+	 * Subclasses may override.
+	 * 
+	 * @param repository
+	 *            the repository
+	 * @since 3.11
+	 */
+	public void applyDefaultCategory(TaskRepository repository) {
+		repository.setCategory(TaskRepository.CATEGORY_BUGS);
+	}
 }
